@@ -20,6 +20,15 @@ def get_data_field(xml, field):
     return str(_get_xml_field(xml, "Data", data_field=field))
 
 
+def get_data(xml):
+    success_xml_entry = _get_xml_field(xml, "Success")
+    try:
+        data = success_xml_entry['Data']
+    except KeyError:
+        data = None
+    return data
+
+
 def parse_to_dict(xml):
     """Return the XML as an OrderedDict."""
     try:
