@@ -1,3 +1,4 @@
+from collections import OrderedDict
 import os
 import subprocess
 import logging
@@ -151,7 +152,10 @@ class LoadMaster(HttpClient):
         response = self._get("/listvs")
         data = get_data(response)
         virtual_services = []
-        for service in data.get('VS', []):
+        services = data.get('VS', [])
+        if type(services) is not list:
+            services = [services]
+        for service in services:
             virt_serv = self.build_virtual_service(service)
             virtual_services.append(virt_serv)
         return virtual_services
