@@ -1,4 +1,4 @@
-from nose.tools import assert_equal
+from nose.tools import assert_equal, assert_raises
 
 # handle py3 and py2 cases:
 try:
@@ -57,3 +57,12 @@ class Test_get_parameter_message:
             assert_equal(msg,"my-loadmaster failed to set 23 ('int' object is not subscriptable)")
         else:
             assert_equal(msg,"my-loadmaster failed to set 23 ('int' object has no attribute '__getitem__')")
+
+
+class Test_MissingInfo:
+
+    def test_call(self):
+        with assert_raises(exceptions.MissingInfo) as err:
+            raise exceptions.MissingInfo('avalue')
+        expect = "My service is missing the parameter_name parameter 'avalue'"
+        assert_equal(str(err.exception), expect)
